@@ -7,4 +7,9 @@
 #' Thankfully it is a rather simple concept that should be easy to gradually
 #' begin to use to greater and greater effect.
 #' @keywords internal
-'_PACKAGE'
\ No newline at end of file
+'_PACKAGE'
+
+## usethis namespace: start
+#' @import rlang
+## usethis namespace: end
+NULL
